@@ -3,7 +3,7 @@
 //3
 //4
 
-//	This is version 2.1 release dated Nov 2008
+//	This is version 2.2 release dated Sep 2009
 
 //	Astrophysics Science Division,
 //	NASA/ Goddard Space Flight Center
@@ -143,7 +143,7 @@ namespace CCfits
                 std::vector<long> inputDimensions(naxis(),1);
                 size_t sNaxis = static_cast<size_t>(naxis());
                 size_t n(std::min(sNaxis,first.size()));
-                std::copy(&first[0],&first[n],&inputDimensions[0]);                
+                std::copy(&first[0],&first[0]+n,&inputDimensions[0]);                
                 for (long i = 0; i < naxis(); ++i)
                 {
 
@@ -310,7 +310,7 @@ namespace CCfits
                                 {
                                         readKey("BLANK",blankVal);
                                         std::valarray<S> copyData(data);
-                                        std::replace(&copyData[0],&copyData[data.size()],
+                                        std::replace(&copyData[0],&copyData[0]+data.size(),
                                                 static_cast<unsigned char>(*nullValue),blankVal);
 
                                         FITSUtil::fill(__tmp,copyData);                                        
@@ -334,7 +334,7 @@ namespace CCfits
                                         {
                                                 readKey("BLANK",blankVal);
                                                 std::valarray<S> copyData(data);
-                                                std::replace(&copyData[0],&copyData[data.size()],
+                                                std::replace(&copyData[0],&copyData[0]+data.size(),
                                                    static_cast<unsigned long>(*nullValue),blankVal);
                                                 FITSUtil::fill(__tmp,copyData);                                        
                                                 phdu.writeImage(first,nElements,__tmp);                          
@@ -354,7 +354,7 @@ namespace CCfits
                                         {
                                                 readKey("BLANK",blankVal);
                                                 std::valarray<S> copyData(data);
-                                                std::replace(&copyData[0],&copyData[data.size()],
+                                                std::replace(&copyData[0],&copyData[0]+data.size(),
                                                      static_cast<long>(*nullValue),blankVal);
 
                                                 FITSUtil::fill(__tmp,copyData);                                        
@@ -378,7 +378,7 @@ namespace CCfits
                                         {
                                                 readKey("BLANK",blankVal);
                                                 std::valarray<S> copyData(data);
-                                                std::replace(&copyData[0],&copyData[data.size()],
+                                                std::replace(&copyData[0],&copyData[0]+data.size(),
                                                    static_cast<unsigned short>(*nullValue),blankVal);
                                                 FITSUtil::fill(__tmp,copyData);                                        
                                                 phdu.writeImage(first,nElements,__tmp);                          
@@ -398,7 +398,7 @@ namespace CCfits
                                         {
                                                 readKey("BLANK",blankVal);
                                                 std::valarray<S> copyData(data);
-                                                std::replace(&copyData[0],&copyData[data.size()],
+                                                std::replace(&copyData[0],&copyData[0]+data.size(),
                                                      static_cast<short>(*nullValue),blankVal);
 
                                                 FITSUtil::fill(__tmp,copyData);                                        
